@@ -2,7 +2,7 @@
 #
 #   build_references.sh - Warn about files containing references to build directories
 #
-#   Copyright (c) 2013-2020 Pacman Development Team <pacman-dev@archlinux.org>
+#   Copyright (c) 2013-2024 Pacman Development Team <pacman-dev@lists.archlinux.org>
 #
 #   This program is free software; you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -21,9 +21,9 @@
 [[ -n "$LIBMAKEPKG_LINT_PACKAGE_BUILD_REFERENCES_SH" ]] && return
 LIBMAKEPKG_LINT_PACKAGE_BUILD_REFERENCES_SH=1
 
-LIBRARY=${LIBRARY:-'/usr/share/makepkg'}
+MAKEPKG_LIBRARY=${MAKEPKG_LIBRARY:-'/usr/share/makepkg'}
 
-source "$LIBRARY/util/message.sh"
+source "$MAKEPKG_LIBRARY/util/message.sh"
 
 lint_package_functions+=('warn_build_references')
 
@@ -37,5 +37,13 @@ warn_build_references() {
 			printf '%s\n' "${refs[@]#"$pkgdir/"}" >&2
 		fi
 	done
+
+	# Check for Windows-style MSYS2 root path
+	if find "${pkgdir}" -type f -print0 | xargs -0 grep -iFqI "$(cygpath -m /)" ; then
+		warning "$(gettext "Package contains reference to %s")" "\$(cygpath -m /)"
+	fi
+	if find "${pkgdir}" -type f -print0 | xargs -0 grep -iFqI "$(cygpath -w /)" ; then
+		warning "$(gettext "Package contains reference to %s")" "\$(cygpath -w /)"
+	fi
 	return 0
 }
